@@ -13,7 +13,7 @@ __all__ = ("embed_youtube", "embed_vimeo", "embed")
 YOUTUBE_RE = re.compile(
     r"""youtu(\.?)be(\.com)?/  # match youtube's domains
         (\#/)? # for mobile urls
-        (embed/)?  # match the embed url syntax
+        (embed/|shorts/|watch/)?  # match the embed/shorts/watch url syntax
         (v/)?
         (watch\?v=)?  # match the youtube page url
         (ytscreeningroom\?v=)?
@@ -71,7 +71,10 @@ def embed_vimeo(url):
     )
 
 
-def embed(url, *, handlers=[embed_youtube, embed_vimeo]):
+_default_handlers = [embed_youtube, embed_vimeo]
+
+
+def embed(url, *, handlers=_default_handlers):
     """embed(url, *, handlers=[embed_youtube, embed_vimeo])
     Run a selection of embedding handlers and return the first value, or
     ``None`` if URL couldn't be processed by any handler.
